@@ -726,7 +726,6 @@ void Bubble::expand_Bubble(int direction, char* path1, char* path2, kmer_type km
     
 }
 
-
 //tries to start a bubble from the current node, first node containing a SNP
 void Bubble::start_Bubble(kmer_type kmer1, int low, int authorised_branching)
 {
@@ -752,9 +751,25 @@ void Bubble::start_Bubble(kmer_type kmer1, int low, int authorised_branching)
             // start bubble for kmer in reverse form
             kmer1 = revcomp(kmer1);
         }
+        
+        // PATCH 20 May 2014: check if the initial kmer can be reverse extended : this allows to test all its possible alternative ends
+        bool exists_previous=false;
+        for(int nt=0; nt<4; nt++)
+        {
+            kmer_type previous_kmer = next_kmer_new(kmer1,nt,1);
+            if(bloom_solid_kmers->contains(previous_kmer) && !debloom->contains(previous_kmer)){
+                exists_previous=true;
+                break;
+            }
+        }
+        if (!exists_previous) continue; // in this case, we can't test the alternative ends of kmer1.
+        // end PATCH
+        
         code2seq(kmer1, seq1);
         code2seq(kmer1, seq2);
         
+        
+        
         for (i=0; i<sizeKmer-1; i++)
         {
             path1[i] = NT2int(seq1[i]);
@@ -825,7 +840,7 @@ void Bubble::start_Bubble(kmer_type kmer1, int low, int authorised_branching)
 void Bubble::find_bubbles(const char * SNP_file_name, int low, int authorised_branching)
 {
     kmer_type kmer;
-    printf("\nSearch for bubbles with threshold %d\n", threshold);
+//    printf("\nSearch for bubbles with threshold %d\n", threshold);
     
     SNP_file=fopen(SNP_file_name,"w");
     if(SNP_file == NULL){
@@ -835,43 +850,6 @@ void Bubble::find_bubbles(const char * SNP_file_name, int low, int authorised_br
     
     printf("Find Bubbles:\n");
     
-    /*char path1[51], path2[51], seq_aux[52];
-     int i;
-     strcpy(seq_aux, "TGTGTGCACACAAGAGTGGCCAGGGTGGAGCCTCGGGATCGGTTGGATAGT");
-     for (i=0; i<2*sizeKmer+1; i++)
-     {
-     path1[i] = NT2int(seq_aux[i]);
-     }
-     printf("\n%d = score of %s\n",filterLowComplexity(path1, 51, 90), seq_aux );
-     strcpy(seq_aux, "TGTGTGCACACAAGAGTGGCCAGGGGGGAGCCTCGGGATCGGTTGGATAGT");
-     for (i=0; i<2*sizeKmer+1; i++)
-     {
-     path2[i] = NT2int(seq_aux[i]);
-     }
-     printf("\n%d = score of %s\n",filterLowComplexity(path2, 51, 90), seq_aux );
-     printf("\n%d = score total\n",filterLowComplexity2Paths(path1, path2, 51, 90));
-     
-     
-     strcpy(seq_aux, "ACTATCCAACCGATCCCGAGGCTCCACCCTGGCCACTCTTGTGTGCACACA");
-     for (i=0; i<2*sizeKmer+1; i++)
-     {
-     path1[i] = NT2int(seq_aux[i]);
-     }
-     printf("\n%d = score of %s\n",filterLowComplexity(path1, 51, 90),seq_aux );
-     strcpy(seq_aux, "ACTATCCAACCGATCCCGAGGCTCCCCCCTGGCCACTCTTGTGTGCACACA");
-     for (i=0; i<2*sizeKmer+1; i++)
-     {
-     path2[i] = NT2int(seq_aux[i]);
-     }
-     printf("\n%d = score of %s\n",filterLowComplexity(path2, 51, 90),seq_aux );
-     printf("\n%d = score total\n",filterLowComplexity2Paths(path1, path2, 51, 90));
-     
-     exit(0);
-     
-     char start_kmer [] = "AACAACAGGTGCTGGAGAGGATGTGGAGAAA";
-     kmer = codeSeed(start_kmer);
-     start_Bubble(kmer, low, authorised_branching);*/
-    
     unsigned long int nb=0;
     off_t nbel = SolidKmers->nb_elements();
     while (SolidKmers->read_element(&kmer))
