@@ -98,7 +98,7 @@ void sorting_count(Bank *Sequences, char *prefix, int max_memory, int max_disk_s
         {
             nb_partitions = (uint32_t) ceil((float) nb_partitions / load_factor);
             nb_partitions = ((nb_partitions * OAHash::size_entry()) + sizeof(key_type)-1) / sizeof(key_type); // also adjust for hash overhead
-            nb_partitions = max((int)(nb_partitions/(optimism+1)), 1);
+            nb_partitions = max((int)(nb_partitions/optimism), 1);
             if (verbose)
                 printf("Updated number of partitions for hash-based k-mer counting: %d\n",nb_partitions);
         }
