@@ -3,7 +3,7 @@
 ###########################################################
 #################### DEFAULT VALUES #######################
 ###########################################################
-version="1.2.5"
+version="1.2.6"
 read_sets="" # FOR instance: "read_set1.fa.gz read_set2.fq.gz"
 prefix="discoRes" # all temp and final files will be written will start with this prefix
 k=31 # size of kmers
@@ -176,16 +176,23 @@ echo
 echo -e "\t#############################################################"
 echo -e "\t#################### KISSREADS MODULE #######################"
 echo -e "\t#############################################################"
-smallk=$(($k-4)) # avoid modify this.
-i=5 #avoid modidy this
 
-$PATH_RS\kissreads $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -c $c -d $d -n -i $i -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent -s #no need to see kissreads option in theory.
+i=4 #avoid modidy this (or increase this if memory needed by kissread is too high. Min 1. Large i (7-10) decreases memory and increases time).
+smallk=$(($k-$i-1)) # DON'T modify this.
+
+
+$PATH_RS\kissreads $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -i $i -O $k -c $c -d $d -n  -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent  #no need to see kissreads option in theory.
 if [ $? -ne 0 ]
 then
-echo "there was a problem with kissnp2, command line: $PATH_RS\kissreads $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -c $c -d $d -n -i $i -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent -s"
+echo "there was a problem with kissnp2, command line: $PATH_RS\kissreads $prefix\_k_$k\_c_$c.fa $read_sets -k $smallk -i $i -O $k -c $c -d $d -n  -o $prefix\_k_$k\_c_$c\_coherent -u $prefix\_k_$k\_c_$c\_uncoherent "
 exit
 fi
 
+
+
+echo -e "\t###############################################################"
+echo -e "\t#################### DISCOSNPs FINISHED #######################"
+echo -e "\t###############################################################"
 #######################################################################
 #################### SORT AND FORMAT COHERENT RESULTS #################
 #######################################################################
@@ -206,10 +213,6 @@ then
 rm -f $prefix\_k_$k\_c_$c.* $prefix\_k_$k\_c_$c\_coherent $prefix\_k_$k\_c_$c\_uncoherent
 fi
 
-
-echo -e "\t###############################################################"
-echo -e "\t#################### DISCOSNPs FINISHED #######################"
-echo -e "\t###############################################################"
 echo -e -n "\t ending date="
 date
 echo -e "\t SNPs are stored in \""$prefix\_k_$k\_c_$c\_coherent.fa"\""
